@@ -50,14 +50,13 @@ def create_wiki_dirs():
 
     try:
         os.mkdir( "wiki" )
-        os.mkdir( "wiki/4.0" )
     except:
         sys.stdout.write( "wiki already generated - the wiki/ subdir exists\n" )
         sys.exit( 1 )
 
     for i in dirs:
         try:
-            os.mkdir( "wiki/4.0" + i )
+            os.mkdir( "wiki/" + i )
         except:
             pass
 
